==> haskell-boring-0.2.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 boring
version:              0.2.1
visibility:           public
id:                   boring-0.2.1-J4SnML7YpXV9bowsupJp7A
key:                  boring-0.2.1-J4SnML7YpXV9bowsupJp7A
license:              BSD-3-Clause
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/boring
synopsis:             Boring and Absurd types
description:
    * @Boring@ types are isomorphic to @()@.

    * @Absurd@ types are isomorphic to @Void@.

    See [What does () mean in Haskell -answer by Conor McBride](https://stackoverflow.com/questions/33112439/what-does-mean-in-haskell/33115522#33115522)

category:             Data
abi:                  33ab031559ae3701e49a83370a8f1f00
exposed:              True
exposed-modules:      Data.Boring
import-dirs:          /usr/lib/ghc-9.4.8/site-local/boring-0.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/boring-0.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/boring-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boring
hs-libraries:         HSboring-0.2.1-J4SnML7YpXV9bowsupJp7A
depends:
    base-4.17.2.1 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-boring/html/boring.haddock
haddock-html:         /usr/share/doc/haskell-boring/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-boring-0.2.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-boring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 boring
version:              0.2.2
visibility:           public
id:                   boring-0.2.2-HI9VvaC9JR142cnMpyID0P
key:                  boring-0.2.2-HI9VvaC9JR142cnMpyID0P
license:              BSD-3-Clause
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/boring
synopsis:             Boring and Absurd types
description:
    * @Boring@ types are isomorphic to @()@.

    * @Absurd@ types are isomorphic to @Void@.

    See [What does () mean in Haskell -answer by Conor McBride](https://stackoverflow.com/questions/33112439/what-does-mean-in-haskell/33115522#33115522)

category:             Data
abi:                  25ccef3608d5cfaf58219ab348cb8bc8
exposed:              True
exposed-modules:      Data.Boring
import-dirs:          /usr/lib/ghc-9.4.8/site-local/boring-0.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/boring-0.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/boring-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boring
hs-libraries:         HSboring-0.2.2-HI9VvaC9JR142cnMpyID0P
depends:
    base-4.17.2.1 tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-boring/html/boring.haddock
haddock-html:         /usr/share/doc/haskell-boring/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
